from typing import Optional
from pydantic import BaseModel, Field as PydanticField
from sqlmodel import SQLModel, Field

class Token(BaseModel):
    access_token: str
    token_type: str
    refresh_token: Optional[str] = None


class TokenData(BaseModel):
    username: Optional[str] = None

class User(SQLModel, table=True):
    id: int = Field(primary_key=True)
    username: str = Field(unique=True, index=True)
    email: str = Field(unique=True)
    hashed_password: str
    disabled: bool = Field(default=False)

class UserRead(BaseModel):
    id: int
    username: str
    email: str
    disabled: bool
    
    class Config:
        from_attributes = True

class UserCreate(BaseModel):
    username: str
    email: str
    password: str

class UserUpdate(BaseModel):
    username: Optional[str] = None
    email: Optional[str] = None
    password: Optional[str] = None


class UserDelete(BaseModel):    
    username: str

class UserLogin(BaseModel):
    username: str
    password: str

class UserLogout(BaseModel):
    username: str

class UserEnable(BaseModel):
    username: str
    disabled: bool = True

class UserDisable(BaseModel):
    username: str
    disabled: bool = False


from setuptools import setup, find_packages

setup(
    name="fastauth_iq",
    version="0.1.0",
    packages=find_packages(),
    py_modules=["fastauth", "User"],
    install_requires=[
        "fastapi>=0.104.0",
        "sqlmodel>=0.0.8",
        "pydantic>=2.5.2",
        "passlib[bcrypt]>=1.7.4", 
        "python-jose[cryptography]>=3.3.0",
        "python-multipart>=0.0.6",
        "pyjwt>=2.6.0",
    ],
    author="Hussein Ghadhban",
    author_email="ala.1995@yahoo.com",
    description="A comprehensive authentication library for FastAPI with JWT and cookie support",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/hu55ain3laa/fastauth",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Framework :: FastAPI",
    ],
    python_requires=">=3.8",
)
